@@ -13,6 +13,7 @@
 #include <QQmlParserStatus>
 #include <QSharedPointer>
 #include <QTimer>
+#include <qqmlintegration.h>
 
 namespace KCalendarCore
 {
@@ -27,6 +28,8 @@ class Incidence;
 class MultiDayIncidenceModel : public QAbstractListModel, public QQmlParserStatus
 {
     Q_OBJECT
+    QML_ELEMENT
+
     Q_INTERFACES(QQmlParserStatus)
     Q_PROPERTY(int periodLength READ periodLength WRITE setPeriodLength NOTIFY periodLengthChanged)
     Q_PROPERTY(MultiDayIncidenceModel::Filters filters READ filters WRITE setFilters NOTIFY filtersChanged)
